package Task::Business::AU;

use strict;
use vars qw{$VERSION};
BEGIN {
	$VERSION = '0.01';
}

1;

__END__

=pod

=head1 NAME

Task::Business::AU - A Task module for Australian Businesses

=head1 DESCRIPTION

There is a gradual awareness in Australia that Open Source is good
for business. But the modules that have been created so far are
somewhat ad-hoc, and scattered around.

The goal for B<Task::Business::AU> is to provide a focus for
the development of Australia-specific Business:: modules, and
provide a single C< cpan Task::Business::AU > command that can be
used to install all the modules in one hit.



=head1 AUTHOR

Adam Kennedy E<lt>cpan@ali.asE<gt>

=head1 SEE ALSO

L<Task>, L<http://phase-n.com/>

=head1 COPYRIGHT

Copyright 2006 Adam Kennedy. All rights reserved.

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.

=cut
